==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/StochRSIIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { StochRSIIndicatorDescription } from "./StochRSIIndicatorDescription";
/**
 * @hidden
 */
export let StochRSIIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class StochRSIIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (StochRSIIndicatorDescriptionMetadata.a == null) {
                StochRSIIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StochRSIIndicatorDescriptionMetadata.c(StochRSIIndicatorDescriptionMetadata.a);
            }
            if (a.k(StochRSIIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(StochRSIIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            StochRSIIndicatorDescriptionMetadata.b(a);
            a.ad("StochRSIIndicator", () => new StochRSIIndicatorDescription());
            a.ac("StochRSIIndicator", StochRSIIndicatorDescriptionMetadata.a);
        }
    }
    StochRSIIndicatorDescriptionMetadata.$t = markType(StochRSIIndicatorDescriptionMetadata, 'StochRSIIndicatorDescriptionMetadata');
    StochRSIIndicatorDescriptionMetadata.a = null;
    return StochRSIIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/StochRSIIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { StochRSIIndicatorDescription } from "./StochRSIIndicatorDescription";
/**
 * @hidden
 */
export let StochRSIIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class StochRSIIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (StochRSIIndicatorDescriptionMetadata.a == null) {
                StochRSIIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StochRSIIndicatorDescriptionMetadata.c(StochRSIIndicatorDescriptionMetadata.a);
            }
            if (a.k(StochRSIIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(StochRSIIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            StochRSIIndicatorDescriptionMetadata.b(a);
            a.ae("StochRSIIndicator", () => new StochRSIIndicatorDescription());
            a.ad("StochRSIIndicator", StochRSIIndicatorDescriptionMetadata.a);
        }
    }
    StochRSIIndicatorDescriptionMetadata.$t = markType(StochRSIIndicatorDescriptionMetadata, 'StochRSIIndicatorDescriptionMetadata');
    StochRSIIndicatorDescriptionMetadata.a = null;
    return StochRSIIndicatorDescriptionMetadata;
})();
